import { isDeepStrictEqual } from 'node:util';
import { Option } from 'commander';
import { ZodArray, ZodBoolean, ZodDefault, ZodEnum, ZodNumber, ZodOptional, ZodSet, } from 'zod';
export default function generateOption(name, schema) {
    let defaultValue;
    let description = schema.description;
    let isOptional = false;
    let flag = `--${name}`;
    // z.string().optional()
    if (schema instanceof ZodOptional) {
        isOptional = true;
        schema = schema._def.innerType;
    }
    // z.string().optional().default()
    if (schema instanceof ZodDefault) {
        isOptional = true;
        defaultValue = schema._def.defaultValue();
        schema = schema._def.innerType;
    }
    // z.string().default().optional()
    if (schema instanceof ZodOptional) {
        isOptional = true;
        schema = schema._def.innerType;
    }
    const expectsValue = !(schema instanceof ZodBoolean);
    if (expectsValue) {
        const isVariadic = schema instanceof ZodArray || schema instanceof ZodSet;
        const rest = isVariadic ? '...' : '';
        flag += isOptional || defaultValue ? ` [value${rest}]` : ` <value${rest}>`;
    }
    const option = new Option(flag, description);
    if (schema instanceof ZodNumber) {
        option.argParser(Number.parseFloat);
    }
    if (schema instanceof ZodEnum) {
        option.choices(schema._def.values);
    }
    if (schema instanceof ZodBoolean && defaultValue === undefined) {
        defaultValue = false;
    }
    if (schema instanceof ZodSet) {
        option.argParser((value, previousValue) => {
            const joinPreviousValue = previousValue instanceof Set &&
                !isDeepStrictEqual(previousValue, defaultValue);
            return joinPreviousValue
                ? new Set([...previousValue, value])
                : new Set([value]);
        });
    }
    if (defaultValue !== undefined) {
        option.default(defaultValue);
        if (defaultValue instanceof Set) {
            option.defaultValueDescription = JSON.stringify([...defaultValue]);
        }
    }
    return option;
}
//# sourceMappingURL=generate-option.js.map